==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp0057_001/MP0057_AddWorkOrderSchedule_001.java <==

package net.datastream.schemas.mp_functions.mp0057_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderschedule_001.WorkOrderSchedule;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_001}WorkOrderSchedule"/>
 *       &lt;/sequence>
 *       &lt;attribute name="ignore_conflict" use="required" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderSchedule" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="AddWorkOrderSchedule" />
 *       &lt;attribute name="productiondaterangeconfirmation" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderSchedule"
})
@XmlRootElement(name = "MP0057_AddWorkOrderSchedule_001")
public class MP0057_AddWorkOrderSchedule_001 {

    @XmlElement(name = "WorkOrderSchedule", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderSchedule_001", required = true)
    protected WorkOrderSchedule workOrderSchedule;
    @XmlAttribute(name = "ignore_conflict", required = true)
    protected boolean ignore_Conflict;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "productiondaterangeconfirmation")
    protected String productiondaterangeconfirmation;

    /**
     * Obtient la valeur de la propriété workOrderSchedule.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderSchedule }
     *     
     */
    public WorkOrderSchedule getWorkOrderSchedule() {
        return workOrderSchedule;
    }

    /**
     * Définit la valeur de la propriété workOrderSchedule.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderSchedule }
     *     
     */
    public void setWorkOrderSchedule(WorkOrderSchedule value) {
        this.workOrderSchedule = value;
    }

    /**
     * Obtient la valeur de la propriété ignore_Conflict.
     * 
     */
    public boolean isIgnore_Conflict() {
        return ignore_Conflict;
    }

    /**
     * Définit la valeur de la propriété ignore_Conflict.
     * 
     */
    public void setIgnore_Conflict(boolean value) {
        this.ignore_Conflict = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_SCHEDULE;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété callname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "AddWorkOrderSchedule";
        } else {
            return callname;
        }
    }

    /**
     * Définit la valeur de la propriété callname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Obtient la valeur de la propriété productiondaterangeconfirmation.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProductiondaterangeconfirmation() {
        if (productiondaterangeconfirmation == null) {
            return "prompt";
        } else {
            return productiondaterangeconfirmation;
        }
    }

    /**
     * Définit la valeur de la propriété productiondaterangeconfirmation.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProductiondaterangeconfirmation(String value) {
        this.productiondaterangeconfirmation = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_functions/mp0057_001/MP0057_AddWorkOrderSchedule_001.java <==

package net.datastream.schemas.mp_functions.mp0057_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderschedule_001.WorkOrderSchedule;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderSchedule_001}WorkOrderSchedule"/>
 *       &lt;/sequence>
 *       &lt;attribute name="ignore_conflict" use="required" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderSchedule" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="AddWorkOrderSchedule" />
 *       &lt;attribute name="productiondaterangeconfirmation" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderSchedule"
})
@XmlRootElement(name = "MP0057_AddWorkOrderSchedule_001")
public class MP0057_AddWorkOrderSchedule_001 {

    @XmlElement(name = "WorkOrderSchedule", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderSchedule_001", required = true)
    protected WorkOrderSchedule workOrderSchedule;
    @XmlAttribute(name = "ignore_conflict", required = true)
    protected boolean ignore_Conflict;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "productiondaterangeconfirmation")
    protected String productiondaterangeconfirmation;

    /**
     * Gets the value of the workOrderSchedule property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderSchedule }
     *     
     */
    public WorkOrderSchedule getWorkOrderSchedule() {
        return workOrderSchedule;
    }

    /**
     * Sets the value of the workOrderSchedule property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderSchedule }
     *     
     */
    public void setWorkOrderSchedule(WorkOrderSchedule value) {
        this.workOrderSchedule = value;
    }

    /**
     * Gets the value of the ignore_Conflict property.
     * 
     */
    public boolean isIgnore_Conflict() {
        return ignore_Conflict;
    }

    /**
     * Sets the value of the ignore_Conflict property.
     * 
     */
    public void setIgnore_Conflict(boolean value) {
        this.ignore_Conflict = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_SCHEDULE;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "AddWorkOrderSchedule";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Gets the value of the productiondaterangeconfirmation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProductiondaterangeconfirmation() {
        if (productiondaterangeconfirmation == null) {
            return "prompt";
        } else {
            return productiondaterangeconfirmation;
        }
    }

    /**
     * Sets the value of the productiondaterangeconfirmation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProductiondaterangeconfirmation(String value) {
        this.productiondaterangeconfirmation = value;
    }

}
